@@ -4,13 +4,13 @@ import java.util.ArrayList;
 
 import org.gcube.portlets.user.td.columnwidget.client.dimension.CodelistSelectionDialog;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.CodelistSelectionListener;
-import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.columnwidget.client.properties.PeriodDataTypeProperties;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.expressionwidget.client.ReplaceExpressionDialog;
 import org.gcube.portlets.user.td.expressionwidget.client.notification.ExpressionWrapperNotification;
 import org.gcube.portlets.user.td.expressionwidget.client.notification.ExpressionWrapperNotification.ExpressionWrapperNotificationListener;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataTypeProperties;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnTypeCodeProperties;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.LocaleTypeProperties;
